@@ -5,7 +5,7 @@ use swc_ecma_visit::Fold;
 
 pub use self::{
     display_name::display_name,
-    jsx::{jsx, parse_expr_for_jsx, JsxDirectives, Options, Runtime},
+    jsx::*,
     jsx_self::jsx_self,
     jsx_src::jsx_src,
     pure_annotations::pure_annotations,
@@ -42,6 +42,7 @@ where
     C: Comments + Clone,
 {
     let Options { development, .. } = options;
+    let development = development.unwrap_or(false);
 
     let refresh_options = options.refresh.take();
 
