@@ -5,7 +5,7 @@ use swc_common::{
     Span, Spanned, SyntaxContext, DUMMY_SP,
 };
 use swc_ecma_ast::*;
-use swc_ecma_utils::{ident::IdentLike, private_ident, quote_ident, quote_str, ExprFactory, Id};
+use swc_ecma_utils::{private_ident, quote_ident, quote_str, ExprFactory};
 use swc_ecma_visit::{as_folder, Fold, Visit, VisitMut, VisitMutWith};
 
 use self::{
@@ -246,37 +246,12 @@ where
 
         let mut should_refresh = self.should_reset;
         if let Some(comments) = &self.comments {
-            comments.with_leading(n.hi - BytePos(1), |comments| {
-                if comments.iter().any(|c| c.text.contains("@refresh reset")) {
-                    should_refresh = true
-                }
-            });
-
-            if should_refresh {
-                self.should_reset = true;
-                return;
-            }
-
-            comments.with_trailing(n.hi, |comments| {
-                if comments.iter().any(|c| c.text.contains("@refresh reset")) {
-                    should_refresh = true
-                }
-            });
-
-            if should_refresh {
-                self.should_reset = true;
-                return;
-            }
-
-            comments.with_leading(n.lo, |comments| {
-                if comments.iter().any(|c| c.text.contains("@refresh reset")) {
-                    should_refresh = true
-                }
-            });
-
-            if should_refresh {
-                self.should_reset = true;
-                return;
+            if n.hi != BytePos(0) {
+                comments.with_leading(n.hi - BytePos(1), |comments| {
+                    if comments.iter().any(|c| c.text.contains("@refresh reset")) {
+                        should_refresh = true
+                    }
+                });
             }
 
             comments.with_trailing(n.lo, |comments| {
